__all__ = [
    'AdditionalLanguage',
    'LocalizationConfig',
]
import enum
import toloka.client.primitives.base
import typing


class AdditionalLanguage(toloka.client.primitives.base.BaseTolokaObject):
    """A translation of a project interface.

    Args:
        language: The language into which the translation is made. Two-letter [ISO 639-1](https://en.wikipedia.org/wiki/List_of_ISO_639-1_codes) language code in upper case.
        public_name: A translated project name.
        public_description: A translated project description.
        public_instructions: Translated instructions for Tolokers.
    """

    class FieldTranslation(toloka.client.primitives.base.BaseTolokaObject):
        """A translation of a text parameter.

        Args:
            value: A translated text.
            source: A translation origin.
        """

        class Source(enum.Enum):
            """A translation origin.

            The only value 'REQUESTER' is supported so far.
            """

            REQUESTER = 'REQUESTER'

        def __init__(
            self,
            *,
            value: typing.Optional[str] = None,
            source: typing.Union[Source, str, None] = ...
        ) -> None:
            """Method generated by attrs for class AdditionalLanguage.FieldTranslation.
            """
            ...

        _unexpected: typing.Optional[typing.Dict[str, typing.Any]]
        value: typing.Optional[str]
        source: typing.Optional[Source]

    def __init__(
        self,
        *,
        language: typing.Optional[str] = None,
        public_name: typing.Optional[FieldTranslation] = None,
        public_description: typing.Optional[FieldTranslation] = None,
        public_instructions: typing.Optional[FieldTranslation] = None
    ) -> None:
        """Method generated by attrs for class AdditionalLanguage.
        """
        ...

    _unexpected: typing.Optional[typing.Dict[str, typing.Any]]
    language: typing.Optional[str]
    public_name: typing.Optional[FieldTranslation]
    public_description: typing.Optional[FieldTranslation]
    public_instructions: typing.Optional[FieldTranslation]


class LocalizationConfig(toloka.client.primitives.base.BaseTolokaObject):
    """All translations of a project interface.

    Args:
        default_language: The main language used for text parameters when the project was created. It is a required parameter.
        additional_languages: A list of translations to other languages.
    """

    def __init__(
        self,
        *,
        default_language: typing.Optional[str] = None,
        additional_languages: typing.Optional[typing.List[AdditionalLanguage]] = ...
    ) -> None:
        """Method generated by attrs for class LocalizationConfig.
        """
        ...

    _unexpected: typing.Optional[typing.Dict[str, typing.Any]]
    default_language: typing.Optional[str]
    additional_languages: typing.Optional[typing.List[AdditionalLanguage]]
